      SUBROUTINE DATA2(ACTION,RSDD,*)
C
C DATA2 reads in the information stored in file
C RSD.D, which supplies data needed to analyze any of the RSD options.
C
C Input: 
C by user:  none
C common blocks:  none
C data file(s):  file with name in RSDD
C subroutine arguments:  none
C
C Output:
C by screen:  none
C data file(s):  none
C common blocks:  FILES, OP1, OP2, OP3
C subroutine arguments:  ACTION
C
C Array subscripts:
C
C CFAIL(25)      - CFAIL(IBY)
C CUTS(3)        - CUTS(1:  Tech type 1, 2:  2, and 3:  4+)
C EFF(3)         - EFF(IP)
C EOPT3(3,15,3)  - EOPT3(Tech type, cutpoint, pollutant)
C EXCESS(3,15,3) - EXCESS(Tech type,ICUT,IP)
C RFAIL(25)      - RFAIL(IBY)
C SENT(25)       - SENT(IBY)
C TOTAL(25)      - TOTAL(IBY)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   ---- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a car first becomes subject to the program
C ACTION  I   Program Type 1, 2, 3, 4, or 5--see RSDDRV
C CARD    I   Three-digit card number from input file
C CFAIL   I   Current number of cars that have failed regular IM testing
C CHARS   C*40 Character data from input file
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EOPT3   R   E value for Option 3, set up the same way as EXCESS
C EXCESS  R   Array of user supplied RSD excess identified fractions
C              dependent upon Tech type, CO cut point, and pollutant,
C              used in Options 1 and 2
C NUMBER  I   Total number of vehicles subject to the inspection program
C OPTION  I   Option number 1, 2, or 3--see RSDDRV
C RFAIL   I   Number of cars expected to fail next years special IM
C              program for cars targetted by RSD
C RSDD    C   Name of input data file
C SCAN    I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C SENT    I   Number of vehicles sent to special IM program via RSD
C TIMES   I   Times per month the RSD sites scanned valid vehicles.
C TOTAL   I   Total vehicles in RSD program, by age
C VMT     I   Vehicle miles travelled, by age
C
C
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 26-Feb-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      CHARACTER CHARS*40, IN1981*40, IN198H*40, INT12*40, INT12H*40
      CHARACTER OUT198*40, OUT19H*40, OUTT12*40, OUTT1H*40, RSDD*40
C
      INTEGER ACTION, AGE, CARD, CFAIL(25), NUMBER, OPTION
      INTEGER RFAIL(25), SCAN, SENT(25), TIMES, TOTAL(25), VMT(25)
C
      REAL CUTS(3), EFF(3), EOPT3(3,15,3), EXCESS(3,15,3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP2/SENT,TOTAL
      COMMON /OP3/CFAIL,RFAIL,EOPT3
      COMMON /FILES/IN1981,IN198H,INT12,INT12H,OUT198,OUT19H,OUTT12,
     &              OUTT1H
C
C First, place hard-coded default data into input data arrays
C
C INPUT/OUTPUT FILENAMES (CARDS 005, 006, 007, 008, 015, 016, 017, 018)
C
      IN1981='IMDATA.D'
      IN198H='HYBRID.IMC'
      INT12= 'TECH12.D'
      INT12H='TECH12.D'
      OUT198='RSDDATA.D'
      OUT19H='RSDDATA.H'
      OUTT12='TECDATA.D'
      OUTT1H='TECDATA.H'
C
C GENERAL DATA AND OPTION 1 DATA (CARDS 021, 022, 023, 024, 031, 032,
C 033, 041, 042, 043, 101 - 125)
C
      NUMBER=1000000
      SCAN=50000
      TIMES=1
      CUTS(1)=3.0
      CUTS(2)=3.0
      CUTS(3)=3.0
      AGE=1
      EFF(1)=0.5
      EFF(2)=0.5
      EFF(3)=0.5
C
      VMT(1)=14390
      VMT(2)=12612
      VMT(3)=12875
      VMT(4)=12180
      VMT(5)=11522
      VMT(6)=10899
      VMT(7)=10310
      VMT(8)=9751
      VMT(9)=9225
      VMT(10)=8726
      VMT(11)=8254
      VMT(12)=7807
      VMT(13)=7386
      VMT(14)=6987
      VMT(15)=6608
      VMT(16)=6251
      VMT(17)=5913
      VMT(18)=5594
      VMT(19)=5291
      VMT(20)=5005
      VMT(21)=4735
      VMT(22)=4478
      VMT(23)=4237
      VMT(24)=4007
      VMT(25)=3790
C
C OPTION 2 DATA have no defaults
C
C OPTION 3 DATA total current failures and commitment to a number of
C failures values have no defaults.  E values for Option 3 are in CARDS
C 401 - 415, 501 - 515, 601 - 615
C
C Fortran first fastest convention for indices:   EOPT3(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (Tech 1, 0.5%, HC), (Tech 2, 0.5%, HC),
C (Tech 4, 0.5%, HC), (Tech 1, 1.0%, HC), ...
C                  (1,1,1)  (2,1,1)  (3,1,1)  (1,2,1)  (2,2,1)  (3,2,1)
C HC
      EOPT3(1,1,1)=3.024
      EOPT3(2,1,1)=3.024
      EOPT3(3,1,1)=2.927
      EOPT3(1,2,1)=2.980
      EOPT3(2,2,1)=2.980
      EOPT3(3,2,1)=3.027
      EOPT3(1,3,1)=3.758
      EOPT3(2,3,1)=3.758
      EOPT3(3,3,1)=3.513
      EOPT3(1,4,1)=4.321
      EOPT3(2,4,1)=4.321
      EOPT3(3,4,1)=3.861
      EOPT3(1,5,1)=2.067
      EOPT3(2,5,1)=2.067
      EOPT3(3,5,1)=4.481
      EOPT3(1,6,1)=2.363
      EOPT3(2,6,1)=2.363
      EOPT3(3,6,1)=5.316
      EOPT3(1,7,1)=2.645
      EOPT3(2,7,1)=2.645
      EOPT3(3,7,1)=5.862
      EOPT3(1,8,1)=1.932
      EOPT3(2,8,1)=1.932
      EOPT3(3,8,1)=6.331
      EOPT3(1,9,1)=1.165
      EOPT3(2,9,1)=1.165
      EOPT3(3,9,1)=6.374
      EOPT3(1,10,1)=1.359
      EOPT3(2,10,1)=1.359
      EOPT3(3,10,1)=6.043
      EOPT3(1,11,1)=1.440
      EOPT3(2,11,1)=1.440
      EOPT3(3,11,1)=7.045
      EOPT3(1,12,1)=1.800
      EOPT3(2,12,1)=1.800
      EOPT3(3,12,1)=9.190
      EOPT3(1,13,1)=1.800
      EOPT3(2,13,1)=1.800
      EOPT3(3,13,1)=8.650
      EOPT3(1,14,1)=2.262
      EOPT3(2,14,1)=2.262
      EOPT3(3,14,1)=9.779
      EOPT3(1,15,1)=1.334
      EOPT3(2,15,1)=1.334
      EOPT3(3,15,1)=10.647
C CO
      EOPT3(1,1,2)=1.831
      EOPT3(2,1,2)=1.831
      EOPT3(3,1,2)=1.984
      EOPT3(1,2,2)=1.922
      EOPT3(2,2,2)=1.922
      EOPT3(3,2,2)=2.437
      EOPT3(1,3,2)=2.043
      EOPT3(2,3,2)=2.043
      EOPT3(3,3,2)=2.794
      EOPT3(1,4,2)=2.329
      EOPT3(2,4,2)=2.329
      EOPT3(3,4,2)=3.134
      EOPT3(1,5,2)=2.618
      EOPT3(2,5,2)=2.618
      EOPT3(3,5,2)=3.682
      EOPT3(1,6,2)=2.931
      EOPT3(2,6,2)=2.931
      EOPT3(3,6,2)=4.264
      EOPT3(1,7,2)=3.016
      EOPT3(2,7,2)=3.016
      EOPT3(3,7,2)=4.861
      EOPT3(1,8,2)=3.367
      EOPT3(2,8,2)=3.367
      EOPT3(3,8,2)=5.361
      EOPT3(1,9,2)=4.135
      EOPT3(2,9,2)=4.135
      EOPT3(3,9,2)=5.002
      EOPT3(1,10,2)=4.339
      EOPT3(2,10,2)=4.339
      EOPT3(3,10,2)=5.018
      EOPT3(1,11,2)=4.934
      EOPT3(2,11,2)=4.934
      EOPT3(3,11,2)=6.051
      EOPT3(1,12,2)=6.167
      EOPT3(2,12,2)=6.167
      EOPT3(3,12,2)=6.644
      EOPT3(1,13,2)=6.167
      EOPT3(2,13,2)=6.167
      EOPT3(3,13,2)=8.285
      EOPT3(1,14,2)=6.356
      EOPT3(2,14,2)=6.356
      EOPT3(3,14,2)=8.469
      EOPT3(1,15,2)=6.368
      EOPT3(2,15,2)=6.368
      EOPT3(3,15,2)=6.340
C NOx
      EOPT3(1,1,3)=0.927
      EOPT3(2,1,3)=0.927
      EOPT3(3,1,3)=0.920
      EOPT3(1,2,3)=0.991
      EOPT3(2,2,3)=0.991
      EOPT3(3,2,3)=0.915
      EOPT3(1,3,3)=0.887
      EOPT3(2,3,3)=0.887
      EOPT3(3,3,3)=0.866
      EOPT3(1,4,3)=0.922
      EOPT3(2,4,3)=0.922
      EOPT3(3,4,3)=0.838
      EOPT3(1,5,3)=0.780
      EOPT3(2,5,3)=0.780
      EOPT3(3,5,3)=0.786
      EOPT3(1,6,3)=0.599
      EOPT3(2,6,3)=0.599
      EOPT3(3,6,3)=0.873
      EOPT3(1,7,3)=0.471
      EOPT3(2,7,3)=0.471
      EOPT3(3,7,3)=0.946
      EOPT3(1,8,3)=0.361
      EOPT3(2,8,3)=0.361
      EOPT3(3,8,3)=0.733
      EOPT3(1,9,3)=0.457
      EOPT3(2,9,3)=0.457
      EOPT3(3,9,3)=0.761
      EOPT3(1,10,3)=0.503
      EOPT3(2,10,3)=0.503
      EOPT3(3,10,3)=0.427
      EOPT3(1,11,3)=0.496
      EOPT3(2,11,3)=0.496
      EOPT3(3,11,3)=0.576
      EOPT3(1,12,3)=0.000
      EOPT3(2,12,3)=0.000
      EOPT3(3,12,3)=0.305
      EOPT3(1,13,3)=0.000
      EOPT3(2,13,3)=0.000
      EOPT3(3,13,3)=0.457
      EOPT3(1,14,3)=0.000
      EOPT3(2,14,3)=0.000
      EOPT3(3,14,3)=0.610
      EOPT3(1,15,3)=0.000
      EOPT3(2,15,3)=0.000
      EOPT3(3,15,3)=0.915
C
C General RSD effectivenesses are in CARDS
C 701 - 715, 801 - 815, 901 - 915
C
C Fortran first fastest convention for indices:  UEXCES(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (Tech 1, 0.5%, HC), (Tech 2, 0.5%, HC),
C (Tech 4, 0.5%, HC), (Tech 1, 1.0%, HC), ...
C                  (1,1,1)  (2,1,1)  (3,1,1)  (1,2,1)  (2,2,1)  (3,2,1)
C HC
      EXCESS(1,1,1)=0.543
      EXCESS(2,1,1)=0.543
      EXCESS(3,1,1)=0.570
      EXCESS(1,2,1)=0.487
      EXCESS(2,2,1)=0.487
      EXCESS(3,2,1)=0.433
      EXCESS(1,3,1)=0.487
      EXCESS(2,3,1)=0.487
      EXCESS(3,3,1)=0.387
      EXCESS(1,4,1)=0.487
      EXCESS(2,4,1)=0.487
      EXCESS(3,4,1)=0.348
      EXCESS(1,5,1)=0.272
      EXCESS(2,5,1)=0.272
      EXCESS(3,5,1)=0.319
      EXCESS(1,6,1)=0.272
      EXCESS(2,6,1)=0.272
      EXCESS(3,6,1)=0.262
      EXCESS(1,7,1)=0.262
      EXCESS(2,7,1)=0.262
      EXCESS(3,7,1)=0.217
      EXCESS(1,8,1)=0.184
      EXCESS(2,8,1)=0.184
      EXCESS(3,8,1)=0.182
      EXCESS(1,9,1)=0.110
      EXCESS(2,9,1)=0.110
      EXCESS(3,9,1)=0.150
      EXCESS(1,10,1)=0.110
      EXCESS(2,10,1)=0.110
      EXCESS(3,10,1)=0.109
      EXCESS(1,11,1)=0.095
      EXCESS(2,11,1)=0.095
      EXCESS(3,11,1)=0.071
      EXCESS(1,12,1)=0.095
      EXCESS(2,12,1)=0.095
      EXCESS(3,12,1)=0.060
      EXCESS(1,13,1)=0.095
      EXCESS(2,13,1)=0.095
      EXCESS(3,13,1)=0.046
      EXCESS(1,14,1)=0.088
      EXCESS(2,14,1)=0.088
      EXCESS(3,14,1)=0.039
      EXCESS(1,15,1)=0.022
      EXCESS(2,15,1)=0.022
      EXCESS(3,15,1)=0.028
C CO
      EXCESS(1,1,2)=0.945
      EXCESS(2,1,2)=0.945
      EXCESS(3,1,2)=0.596
      EXCESS(1,2,2)=0.899
      EXCESS(2,2,2)=0.899
      EXCESS(3,2,2)=0.499
      EXCESS(1,3,2)=0.758
      EXCESS(2,3,2)=0.758
      EXCESS(3,3,2)=0.442
      EXCESS(1,4,2)=0.751
      EXCESS(2,4,2)=0.751
      EXCESS(3,4,2)=0.396
      EXCESS(1,5,2)=0.676
      EXCESS(2,5,2)=0.676
      EXCESS(3,5,2)=0.352
      EXCESS(1,6,2)=0.662
      EXCESS(2,6,2)=0.662
      EXCESS(3,6,2)=0.278
      EXCESS(1,7,2)=0.584
      EXCESS(2,7,2)=0.584
      EXCESS(3,7,2)=0.213
      EXCESS(1,8,2)=0.489
      EXCESS(2,8,2)=0.489
      EXCESS(3,8,2)=0.178
      EXCESS(1,9,2)=0.467
      EXCESS(2,9,2)=0.467
      EXCESS(3,9,2)=0.133
      EXCESS(1,10,2)=0.420
      EXCESS(2,10,2)=0.420
      EXCESS(3,10,2)=0.107
      EXCESS(1,11,2)=0.398
      EXCESS(2,11,2)=0.398
      EXCESS(3,11,2)=0.072
      EXCESS(1,12,2)=0.398
      EXCESS(2,12,2)=0.398
      EXCESS(3,12,2)=0.053
      EXCESS(1,13,2)=0.398
      EXCESS(2,13,2)=0.398
      EXCESS(3,13,2)=0.044
      EXCESS(1,14,2)=0.308
      EXCESS(2,14,2)=0.308
      EXCESS(3,14,2)=0.034
      EXCESS(1,15,2)=0.205
      EXCESS(2,15,2)=0.205
      EXCESS(3,15,2)=0.017
C NOx
      EXCESS(1,1,3)=0.436
      EXCESS(2,1,3)=0.436
      EXCESS(3,1,3)=0.283
      EXCESS(1,2,3)=0.423
      EXCESS(2,2,3)=0.423
      EXCESS(3,2,3)=0.178
      EXCESS(1,3,3)=0.335
      EXCESS(2,3,3)=0.335
      EXCESS(3,3,3)=0.122
      EXCESS(1,4,3)=0.295
      EXCESS(2,4,3)=0.295
      EXCESS(3,4,3)=0.091
      EXCESS(1,5,3)=0.232
      EXCESS(2,5,3)=0.232
      EXCESS(3,5,3)=0.059
      EXCESS(1,6,3)=0.146
      EXCESS(2,6,3)=0.146
      EXCESS(3,6,3)=0.054
      EXCESS(1,7,3)=0.118
      EXCESS(2,7,3)=0.118
      EXCESS(3,7,3)=0.042
      EXCESS(1,8,3)=0.067
      EXCESS(2,8,3)=0.067
      EXCESS(3,8,3)=0.018
      EXCESS(1,9,3)=0.067
      EXCESS(2,9,3)=0.067
      EXCESS(3,9,3)=0.015
      EXCESS(1,10,3)=0.063
      EXCESS(2,10,3)=0.063
      EXCESS(3,10,3)=0.009
      EXCESS(1,11,3)=0.052
      EXCESS(2,11,3)=0.052
      EXCESS(3,11,3)=0.006
      EXCESS(1,12,3)=0.000
      EXCESS(2,12,3)=0.000
      EXCESS(3,12,3)=0.003
      EXCESS(1,13,3)=0.000
      EXCESS(2,13,3)=0.000
      EXCESS(3,13,3)=0.003
      EXCESS(1,14,3)=0.000
      EXCESS(2,14,3)=0.000
      EXCESS(3,14,3)=0.003
      EXCESS(1,15,3)=0.000
      EXCESS(2,15,3)=0.000
      EXCESS(3,15,3)=0.003
C
C Second, overwrite input data arrays with information obtained from
C the input data file
C
C Open the input data file
C
      OPEN(UNIT=2,FILE=RSDD,STATUS='OLD',ERR=350)
C
C Read data from the input data file
C
      WRITE(UNIT=*,FMT=200)RSDD
 200  FORMAT(/,  ' Now reading data from the input data file ',
     &       1X,A40,/)
C
C Start loop to sequentially examine every card
C
 10   CONTINUE
C
C Read current card (leave loop at eof; trap any read errors that
C  occur)
C
      READ(UNIT=2,FMT=210,END=99,ERR=352)CARD,CHARS
 210  FORMAT(I3,1X,A33)
C
C If current card is 000, a comment card, read next card
C
      IF (CARD.EQ.0) GO TO 10
C
      IF (CARD.LE.100) THEN
C
C Find control values, filenames, general information, and some
C Option 1 data
C
C               1  2  3  4  5  6  7  8  9  0  1  2  3  4  5  6  7  8  9
        GO TO ( 1, 2,20,20, 5, 6, 7, 8,20,20,20,20,20,20,15,16,17,18,20,
     &      20,21,22,23,24,20,20,20,20,20,20,31,32,33,20,20,20,20,20,20,
     &      20,41,42,43) CARD
C            0  1  2  3  4  5  6  7  8  9  0  1  2  3
        GO TO 20
 1      READ(UNIT=CHARS(10:11),FMT=*,ERR=360)OPTION
        IF ( (OPTION.LT.1).OR.(OPTION.GT.3) ) GO TO 354
        GO TO 10
 2      READ(UNIT=CHARS(10:11),FMT=*,ERR=360)ACTION
        IF ( (ACTION.LT.1).OR.(ACTION.GT.5) ) GO TO 356
        GO TO 10
 5      IN1981=CHARS
        GO TO 10
 6      IN198H=CHARS
        GO TO 10
 7      INT12=CHARS
        GO TO 10
 8      INT12H=CHARS
        GO TO 10
 15     OUT198=CHARS
        GO TO 10
 16     OUT19H=CHARS
        GO TO 10
 17     OUTT12=CHARS
        GO TO 10
 18     OUTT1H=CHARS
        GO TO 10
 21     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)NUMBER
        GO TO 10
 22     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)SCAN
        GO TO 10
 23     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)TIMES
        IF ( (TIMES.LT.1).OR.(TIMES.GT.11) ) GO TO 362
        GO TO 10
 24     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)AGE
        IF ( (AGE.LT.1).OR.(AGE.GT.24) ) GO TO 362
        GO TO 10
 31     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CUTS(1)
        IF ( ( (CUTS(1).LT.0.5).OR.(CUTS(1).GT.7.5) ).AND.
     &       (  CUTS(1).NE.99.9  ) ) GO TO 362
        GO TO 10
 32     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CUTS(2)
        IF ( ( (CUTS(2).LT.0.5).OR.(CUTS(2).GT.7.5) ).AND.
     &       (  CUTS(2).NE.99.9  ) ) GO TO 362
        GO TO 10
 33     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CUTS(3)
        IF ( ( (CUTS(3).LT.0.5).OR.(CUTS(3).GT.7.5) ).AND.
     &       (  CUTS(3).NE.99.9  ) ) GO TO 362
        GO TO 10
 41     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EFF(1)
        IF ( (EFF(1).LE.0.0).OR.(EFF(1).GT.1.0) ) GO TO 362
        GO TO 10
 42     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EFF(2)
        IF ( (EFF(2).LE.0.0).OR.(EFF(2).GT.1.0) ) GO TO 362
        GO TO 10
 43     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EFF(3)
        IF ( (EFF(3).LE.0.0).OR.(EFF(3).GT.1.0) ) GO TO 362
        GO TO 10
      ELSE
C
C 101 =< CARD =< 125
C
        IF ( (CARD.GE.101).AND.(CARD.LE.125) ) THEN
C
C Find VMT data (for Option 1)
C
          READ(UNIT=CHARS(1:11),FMT=*,ERR=360)VMT(CARD-100)
          GO TO 10
        ELSE
C
C 201 =< CARD =< 225
C
          IF ( (CARD.GE.201).AND.(CARD.LE.225) ) THEN
C
C Find total vehicles by age and vehicles sent to I/M via RSD
C by age (for Option 2)
C
            READ(UNIT=CHARS(1:11),FMT=*,ERR=360)TOTAL(CARD-200)
            READ(UNIT=CHARS(12:22),FMT=*,ERR=360)SENT(CARD-200)
            IF ( SENT(CARD-200).GT.TOTAL(CARD-200) ) GO TO 364
            GO TO 10
          ELSE
C
C 301 =< CARD =< 325
C
            IF ( (CARD.GE.301).AND.(CARD.LE.325) ) THEN
C
C Find current RSD failures by age and the commitment to next
C year's I/M failures provided by RSD by age (for Option 3)
C
              READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CFAIL(CARD-300)
              READ(UNIT=CHARS(12:22),FMT=*,ERR=360)RFAIL(CARD-300)
              IF ( RFAIL(CARD-300).GT.CFAIL(CARD-300) ) GO TO 366
              GO TO 10
            ELSE
C
C 401 =< CARD =< 415
C
              IF ( (CARD.GE.401).AND.(CARD.LE.415) ) THEN
C
C Find Option 3 E values for all Tech types and all cutpoints
C for HC
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EOPT3(1,CARD-400,1)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EOPT3(2,CARD-400,1)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EOPT3(3,CARD-400,1)
                GO TO 10
              ELSE
C
C 501 =< CARD =< 515
C
                IF ( (CARD.GE.501).AND.(CARD.LE.515) ) THEN
C
C Find Option 3 E values for all Tech types and all cutpoints
C for CO
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EOPT3(1,CARD-500,2)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EOPT3(2,CARD-500,2)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EOPT3(3,CARD-500,2)
                  GO TO 10
                ELSE
C
C 601 =< CARD =< 615
C
                  IF ( (CARD.GE.601).AND.(CARD.LE.615) ) THEN
C
C Find Option 3 E values for all Tech types and all cutpoints
C for NOx
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EOPT3(1,CARD-600,3)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EOPT3(2,CARD-600,3)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EOPT3(3,CARD-600,3)
                    GO TO 10
                  ELSE
C
C 701 =< CARD =< 715
C
                    IF ( (CARD.GE.701).AND.(CARD.LE.715) ) THEN
C
C Find RSD effectivenesses for all Tech types and all cutpoints
C for HC (for Options 1 and 2)
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EXCESS(1,CARD-700,1)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EXCESS(2,CARD-700,1)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EXCESS(3,CARD-700,1)
                      GO TO 10
                    ELSE
C
C 801 =< CARD =< 815
C
                      IF ( (CARD.GE.801).AND.(CARD.LE.815) ) THEN
C
C Find RSD effectivenesses for all Tech types and all cutpoints
C for CO (for Options 1 and 2)
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EXCESS(1,CARD-800,2)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EXCESS(2,CARD-800,2)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EXCESS(3,CARD-800,2)
                        GO TO 10
                      ELSE
C
C 901 =< CARD =< 915
C
                        IF ( (CARD.GE.901).AND.(CARD.LE.915) ) THEN
C
C Find RSD effectivenesses for all Tech types and all cutpoints
C for NOx (for Options 1 and 2)
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EXCESS(1,CARD-900,3)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EXCESS(2,CARD-900,3)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EXCESS(3,CARD-900,3)
                          GO TO 10
                        END IF
C
                      END IF
C
                    END IF
C
                  END IF
C
                END IF
C
              END IF
C
            END IF
C
          END IF
C
        END IF
C
      END IF
C
 20   CONTINUE
C
C CARD number is invalid
C
      PRINT *,'CARD NUMBER ',CARD,' IS INVALID'
      GO TO 98
C
 350  PRINT *,'PROBLEM OPENING FILE ',RSDD
      GO TO 98
C
 352  PRINT *,'PROBLEM READING A RECORD FROM FILE ',RSDD
      GO TO 98
C
 354  PRINT *,'THIS OPTION IS NOT ALLOWED: ',OPTION,' IN CARD ',CARD
      GO TO 98
C
 356  PRINT *,'THIS PROGRAM TYPE NOT ALLOWED: ',ACTION,' IN CARD ',CARD
      GO TO 98
C
 362  PRINT *,'VARIABLE FROM CARD ',CARD,' IS OUT OF RANGE'
      GO TO 98
C
 364  PRINT *,'NO. OF VEHICLES SENT TO RSD > TOTAL VEH. IN MODEL YR., '
      PRINT *,'IN CARD ',CARD
      GO TO 98
C
 366  PRINT *,'RSD IM FAILURE COMMITMENT > PREVIOUS YEAR IM FAILURES, '
      PRINT *,'IN CARD ',CARD
      GO TO 98
C
 360  PRINT *,'ERROR WHEN READING VARIABLE(S) FROM CHAR STRING OF '
      PRINT *,'CARD: ',CARD,' IN FILE ',RSDD
      PRINT *,' '
C
 98   CONTINUE
      CLOSE(2)
      RETURN 1
C
 99   CONTINUE
C
      CLOSE(2)
      RETURN
      END
