      SUBROUTINE IM1(IN1981,OUT198,NVSEEB,UEXCE4,RSDD)
C
C IM1
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD) 
C from the existing 1981 and newer model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in IN1981
C subroutine arguments:  IN1981, OUT198, NVSEEB, UEXCE4, RSDD
C
C Output:
C by screen:  none
C common blocks(s):  none
C data file(s):  file whose name is passed in OUT198
C subroutine arguments:  none
C
C Array subscripts:
C
C ACREDT(24,3,18) - ACREDT(IBY,IP,IMY)
C BCREDT(24)      - BCREDT(IBY)
C CUTS(3)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C EXCESS(3,15,3)  - EXCESS(ITECH,cutpoint,IP)
C NCREDT(24)      - NCREDT(IBY)
C NVSEEB(25)      - NVSEEB(IBY)
C SMARK(4)        - SMARK(ISMART)
C SMART(4)        - SMART(ISMART)
C UEXCE4(3)       - UEXCE4(IP)
C VMT(25)         - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -  
C ACREDT  R   Array of annual credits read from the input file
C AGE     I   Age at which a veh. first becomes subject to RSD program
C BCREDT  R   Array of biennial credits read from the input file
C CCUTCO  R   CO cut point read from an input file annual Smart line
C CCUTHC  R   HC cut point read from an input file annual Smart line
C CCUTNO  R   NOx cut point read from an input file annual Smart line
C CKUTCO  R   CO cut point read from an input file biennial Smart line
C CKUTHC  R   HC cut point read from an input file biennial Smart line
C CKUTNO  R   NOx cut point read from an input file biennial Smart line
C CRDCOM  C   Char. string of comments from the end of a credit line 
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5 (not used here)
C ETCFLG  I   Etc. flag, may be used for something in the future
C EXCESS  R   See routines R1 and R2
C FLAG    I   The next Smart line to be examined for annual data is
C              FLAG+1 Smart lines from the top of the input file
C HYBFLG  I   Hybrid program flag
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              IMDATA; 2 if data was changed
C IMNAME  C   Character string of comments from the end of an annual
C              Smart line
C IMY     I   Counter for model year
C IN1981  C   Character string name of the IMDATA.D type input filename
C IP      I   Counter for pollutants
C IREC    I   Counter for credit lines
C ISMART  I   Counter for digits in the Smart control strip
C ITECH   I   Counter for Tech type: 1 is 1, 2 is 2, and 3 is 4+
C NCREDT  R   Array of new biennial credits
C NUMBER  I   Total number of vehicles subject to the I/M program.
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial, function of
C              benefit year
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUT198  C   Char. string name of the RSDDATA.D type output filename
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array holding the first four digits of a biennial Smart
C              line (the Smart control strip):  altitude 1=Low 2=High; 
C              frequency 1=annual 2=biennial; technology 1=TECH1&2
C              2=TECH4+; test type 1=Idle 2=2500/Idle 3=Loaded/Idle
C              4=IM240 Test
C SMART   I   Array holding the 1st four digits of an annual Smart line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE4  R   Effectiveness of RSD machines at detecting high emitters,
C              function of pollutant for Tech 4+ vehicles
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Tech 1 refers to pre-1975 vehicles, Tech 2 to those from
C         1975-1980, and Tech 4+ to those of 1981 and later.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 19-Mar-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      CHARACTER CRDCOM*19, IMNAME*80, IN1981*40, OUT198*40, RSDD*40
C
      INTEGER AGE, ETCFLG, FLAG, HYBFLG, IBY, ILINE, IMFLG, IMY, IP
      INTEGER IREC, ISMART, NUMBER, OLDFLG, OPTION, SCAN, SMARK(4)
      INTEGER SMART(4), TIMES, VMT(25)
C
      REAL ACREDT(24,3,18), BCREDT(24), CCUTHC, CCUTCO, CCUTNO
      REAL CKUTHC, CKUTCO, CKUTNO, CUTS(3), EFF(3), EXCESS(3,15,3)
      REAL NCREDT(24), NVSEEB(25), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1981 and newer model ',
     &            'years vehicles I/M credits to include ',/,
     &           ' Remote Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '------------------------------------- ')
C
C ----------
C OPEN FILES
C ----------
C
      OPEN(UNIT=2,FILE=IN1981,ERR=300,STATUS='OLD')
      OPEN(UNIT=3,FILE=OUT198,ERR=305)
C
C ------------------
C START PROCESS LOOP
C ------------------
C
C Set FLAG=0.  This means that the first Smart line in the file is the
C line to check to see if it is one marking annual data.
C
      FLAG=0
C
C Set OLDFLG=0.  This means that data is new, i.e., it has HYBFLG,
C IMFLG, and ETCFLG.  If it is 1, it means that these don't exist and
C the data is old data.
C
      OLDFLG=0
C
 50   CONTINUE
C
C The following section of code jumps ahead in the data file to the
C first Smart line after the last Smart line marking annual data.
C Jumping ahead means reading one or more sets (a Smart line, 18 year
C sets composed of an HC line, a CO line, and a NOx line--55 lines in 
C all) of data so that the next record to be read will be a Smart line.
C
      DO 10 ILINE=1,FLAG
C
        DO 15 IREC=1,55
          READ(2,100,END=20)
 100      FORMAT(1X)
 15     CONTINUE
C
 10   CONTINUE
C
C Read the Smart control strip, cut point values and description line
C
 30   CONTINUE
C
      READ(2,102,END=20,ERR=310) (SMART(ISMART),ISMART=1,4),
     &     CCUTHC,CCUTCO,CCUTNO,IMNAME
 102  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,A80)
C
      READ(IMNAME,105,ERR=22)HYBFLG,IMFLG,ETCFLG
 105  FORMAT(3I1)
C
      GO TO 23
C
 22   CONTINUE
C
C An error in reading flags from IMNAME means that they aren't there;
C thus input data is old-type data.
C
      OLDFLG=1
C
 23   CONTINUE
C
C Reading a Smart line; looking for annual data
C
C Increment FLAG, since the next Smart line that can mark annual data
C must be below the current Smart line
C
      FLAG=FLAG+1
C
C Check to see if the current Smart line marks annual data
C
      IF (SMART(2).NE.1) THEN
C
C Not annual; jump forward to the next Smart line and read it
C
        DO 25 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 25     CONTINUE
C       
        GO TO 30
      END IF
C
C The current Smart line marks annual data.  Echo the annual Smart   
C line to the new file
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C Halt processing if the annual Smart line has a value
C of IMFLG that is not one, because this means that the annual
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
        WRITE(3,215)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,CCUTNO,
     &              HYBFLG,ETCFLG,OPTION,RSDD
 215    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,' New ',
     &         'annual credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,216)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,CCUTNO,
     &              OPTION,RSDD
 216    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the annual data--loop for the 18 model years stored in the record
C and
C
      PRINT *,'Reading old annual credits and echoing old annual ',
     & 'credits'
C
      DO 35 IMY=1,18
C
C loop for the 3 pollutants (HC, CO, and NOX) in the record--
C
        DO 36 IP=1,3
          READ(2,110,END=315,ERR=320)(ACREDT(IBY,IP,IMY),IBY=1,24),
     &                               CRDCOM
 110      FORMAT(24F5.3,A19)
C
C and write the data to the new file
C
          WRITE(3,220,ERR=325)(ACREDT(IBY,IP,IMY),IBY=1,24),CRDCOM
 220      FORMAT(24F5.3,A19)
 36     CONTINUE
C
 35   CONTINUE
C
C Go back to beginning of the data file to begin the search for the
C biennial Smart line corresponding to the above annual Smart line
C
      REWIND(2)
C
C Read current Smart line
C
 40   CONTINUE
C
C If old data, don't try to read flags after cutpoints
C
      IF (OLDFLG.EQ.1) THEN
C
        READ(2,112,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO
 112    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
      ELSE
C
C New data, so read the flags
C
        READ(2,115,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO,HYBFLG,IMFLG,ETCFLG
 115    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,3I1)
      ENDIF
C
C Reading a Smart line; looking for biennial data
C
C If it is not the matching biennial Smart line, read the next Smart
C line
C
      IF ( (SMARK(1).NE.SMART(1)) .OR. (SMARK(2).NE.2) .OR.
     &     (SMARK(3).NE.SMART(3)) .OR. (SMARK(4).NE.SMART(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 38 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 38     CONTINUE
C
        GO TO 40
      END IF
C
C Now that a match has been found, output new biennial results;
C write new biennial credit Smart line.
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C But halt processing if the matching biennial Smart line has a value
C of IMFLG that is not one, because this means that the biennial
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
C Found matching biennial data; writing new credits
C
        WRITE(3,235,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 235    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,236,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 236    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the biennial credits.
C
      PRINT *,'Reading old biennial credits and writing new biennial ',
     & 'credits'
C
C Loop for the 18 model years stored in the record.
C
      DO 45 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 46 IP=1,3
C
C Loop for the 24 age credit values
C
          READ(2,120,END=340,ERR=345)(BCREDT(IBY),IBY=1,24),CRDCOM
 120      FORMAT(24F5.3,A19)
C
C Calculate the new biennial credit.
C
          DO 48 IBY=1,24
C
              NCREDT(IBY) = BCREDT(IBY) + ( ACREDT(IBY,IP,IMY)
     &                      - BCREDT(IBY) ) * NVSEEB(IBY) * UEXCE4(IP)
C
 48       CONTINUE
C
          WRITE(3,240,ERR=325)(NCREDT(IBY),IBY=1,24),CRDCOM
 240      FORMAT(24F5.3,A19)
C
 46    CONTINUE
C
 45   CONTINUE
C
C Now go back up to the procedure for finding the next annual Smart
C line that has not been processed yet.
C
      REWIND(2)
C
      GO TO 50
C
C --------------
C ERROR MESSAGES
C --------------
C
 300  CONTINUE
      WRITE(*,301)IN1981       
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GO TO 55
C
 305  CONTINUE
      WRITE(*,306)OUT198       
 306  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 55
C
 310  CONTINUE
      WRITE(*,311)IN1981       
 311  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 315  CONTINUE
      WRITE(*,316)IN1981       
 316  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 320  CONTINUE
      WRITE(*,321)IN1981       
 321  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 325  CONTINUE
      WRITE(*,326)OUT198       
 326  FORMAT(/,  ' ERROR WRITING ANNUAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 330  CONTINUE
      WRITE(*,331)IN1981       
 331  FORMAT(/,  ' ERROR NO MATCHING BIENNIAL DATA IN ',
     &            'INPUT FILE ',A40)
      GO TO 55
C
 332  CONTINUE
      WRITE(*,333)       
 333  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS TO DATA ',
     &            'THAT HAS ALREADY BEEN CHANGED ')
      GO TO 55
C
 335  CONTINUE
      WRITE(*,336)OUT198       
 336  FORMAT(/,  ' ERROR WRITING BIENNIAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 340  CONTINUE
      WRITE(*,341)IN1981       
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'BIENNIAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 345  CONTINUE
      WRITE(*,346)IN1981       
 346  FORMAT(/,  ' ERROR READING BIENNIAL CREDIT FROM ',
     &            'INPUT FILE ',A40)
C
C -----------------
C END OF PROCEDURES
C -----------------
C
 55   CONTINUE
      WRITE(*,350)       
 350  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY',/)
      GO TO 60
C
 20   CONTINUE
      WRITE(*,245)       
 245  FORMAT(/,  ' Conversion ended normally',/)
C
 60   CONTINUE
C
      CLOSE (3)
      CLOSE (2)
C
      RETURN
      END
