      SUBROUTINE INPUT(RSDD)
C
C INPUT calls DATA2 in order to read in the information stored in file
C RSD.D, which supplies data needed to analyze any of the RSD options.
C It then calls R1, R2, or R3, depending on which option is chosen in
C order to find the fraction of vehicles "seen" by RSD, and the
C effectiveness of RSD in detecting the high emitters in the population
C it "sees".  These values are determined by the option chosen.
C Finally, it calls the IM# and TECH# pair of routines, where # is the
C RSD program number, ACTION.
C
C Called by RSDDRV (main)
C
C Calls subroutines DATA2; R1, R2, or R3; and IM1 and TECH1, IM2 and
C TECH2, IM3 and TECH3, IM4 and TECH4, or IM5 and TECH5
C
C Input: 
C by user:  none
C common blocks:  FILES, OP1, OP2, OP3
C data file(s): none
C subroutine arguments:  RSDD
C 
C Output:
C by screen:  none
C common blocks:  OP1, OP2, OP3
C data file(s):  none
C subroutine arguments:  none
C
C Array subscripts:
C
C ACUTS(3)       - ACUTS(ITECH)
C CUTS(3)        - CUTS(ITECH)
C EFF(3)         - EFF(IP)
C EOPT3(3,15,3)  - EOPT3(ITECH,cutpoint,IP)
C EXCESS(3,15,3) - EXCESS(ITECH,cutpoint,IP)
C NVSEEA(25)     - NVSEEA(benefit year)
C NVSEEB(25)     - NVSEEB(benefit year)
C UEXCE1(3)      - UEXCE1(pollutant)
C UEXCE2(3)      - UEXCE2(pollutant)
C UEXCE4(3)      - UEXCE4(pollutant)
C VMT(25)        - VMT(vehicle age)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C ACUTS   C   Array of character strings depending on the values of the
C              CUTS array: if an element of the CUTS array is 99.9, the
C              corresponding ACUTS element will be 'ASSUMES NO';
C              otherwise, it will be 'assumes an'
C ACTION  I   Program Type--see RSDDRV
C AGE     I   The age at which a car first becomes subject to the program
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups 
C              pre-1975, 1975-1980, and post-1980
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EOPT3   R   Array of user supplied RSD E values for Option 3
C              stored by Tech type, CO cutpoint, and pollutant (the same
C              way that values are stored in UEXCES in R1.FOR)
C EXCESS  R   Array of user supplied RSD excess detected fractions
C              stored by Tech type, CO cutpoint, and pollutant (the same
C              way that values are stored in UEXCES in R1.FOR)
C IAGE    I   Age counter
C IN1981  C   Character string name of the IMDATA.D type input file
C IN198H  C   Character string name of the HYBRID.IMC type input file
C INT12   C   Character string name of the TECH12.D type input file
C INT12H  C   ... name of Tech 1 & 2 Retest-Hybrid IM data input file
C ITECH   I   1 is tech type 1, 2 is 2, and 3 is 4
C NUMBER  I   Total number of vehicles subject to the inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C OPTION  I   Option--see RSDDRV
C OUT198  C   Character string name of the RSDDATA.D type output file
C OUT19H  C   Char. string name of the Tech4+ Retest-Hybrid output file
C OUTT12  C   Character string name of the TECDATA.D type output file
C OUTT1H  C   Char. string name of the Tech1&2 Retest-Hybrid output file
C RSDD    C   Char. string for name of the input data file
C SCAN    I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C TIMES   I   Times per month the RSD sites scanned valid vehicles.
C UXECE1  R   Effectiveness of RSD, Tech type 1
C UEXCE2  R   Effectiveness of RSD, Tech type 2
C UEXCE4  R   Effectiveness of RSD, Tech type 4+
C VMT     I   Vehicle miles travelled per year, by age
C
C
C Notes:
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C 26-Feb-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 03-Jun-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C Disable clean-screening (Program 5.) temporarily
C
C
C Declare variables
C
      CHARACTER ACUTS(3)*10, IN1981*40, IN198H*40, INT12*40, INT12H*40
      CHARACTER OUT198*40, OUT19H*40, OUTT12*40, OUTT1H*40, RSDD*40
C
      INTEGER ACTION, AGE, CFAIL(25), IAGE, ICUT, IP, ITECH, NUMBER
      INTEGER OPTION, RFAIL(25), SCAN, SENT(25), TIMES, TOTAL(25)
      INTEGER VMT(25)
C
      REAL CUTS(3), EFF(3), EOPT3(3,15,3), EXCESS(3,15,3), NVSEEA(25)
      REAL NVSEEB(25), UEXCE1(3), UEXCE2(3), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP2/SENT,TOTAL
      COMMON /OP3/CFAIL,RFAIL,EOPT3
      COMMON /FILES/IN1981,IN198H,INT12,INT12H,OUT198,OUT19H,OUTT12,
     &              OUTT1H
C
C Read in data from the input file, RSDD
C
      CALL DATA2(ACTION,RSDD,*99)
C
C The following is used for echo only:
C Make cutpoint notes
C
C Examine CO cutpoints; if a cutpoint was set to 99.9,
C make a note in ACUTS that processing of its
C associated tech type biennial credits will be skipped.
C
      DO 75 ITECH=1,3
C
        IF (CUTS(ITECH).EQ.99.9) THEN
          ACUTS(ITECH)='ASSUMES NO'
        ELSE
          ACUTS(ITECH)='assumes an'
        END IF
C
 75   CONTINUE
C
      IF (ACTION.EQ.5) THEN
        PRINT *,'Program type 5. has not been completed and cannot'
        PRINT *,"be modeled at this time."
        GO TO 99
      END IF
C
      IF ( (OPTION.EQ.3).AND.(ACTION.EQ.5) ) THEN
        PRINT *,'The combination of program parameters Option 3. and ',
     & 'Program Type 5. cannot'
        PRINT *,"be modeled.  Please refer to the Users' Guide."
        GO TO 99
      END IF
C
      PRINT *,'Option is ',OPTION
      PRINT *,'Program Type is ',ACTION
C
C Show data file variable values pertaining to option chosen
C
      IF (OPTION.EQ.1) THEN
        WRITE(*,270)NUMBER,SCAN,TIMES,CUTS(1),ACUTS(1),CUTS(2),ACUTS(2),
     &              CUTS(3),ACUTS(3),AGE,EFF(1),EFF(2),EFF(3)
 270    FORMAT(   ' Option #1 input data file information: ',/,
     &              1X,I9,'  Number of vehicles in program ',/,
     &              1X,I9,'  Valid vehicle measurements ',
     &              'per month ',/,
     &              8X,I2,'  Number of times a vehicle ',
     &              'must be scanned ',/,
     &              4X,F6.3,'  CO cutpoint for 1974 and ',
     &              'older model year vehicles; ',/,
     &                          15X,'(',A10,' RSD program ',
     &              'for 1974 and older model year vehicles) ',/,
     &              4X,F6.3,'  CO cutpoint for 1975 through ',
     &              '1980 model year vehicles; ',/,
     &                          15X,'(',A10,' RSD program ',
     &              'for 1975 - 1980 model year vehicles) ',/,
     &              4X,F6.3,'  CO cutpoint for 1981 and ',
     &              'newer model year vehicles; ',/,
     &                          15X,'(',A10,' RSD program ',
     &              'for 1981 and newer model year vehicles) ',/,
     &              8X,I2,'  Age at which a vehicle first ',
     &              'becomes subject to program ',/,
     &              6X,F4.2,'  Effectiveness of Test and Repair ',
     &              'program vs. Test Only, for HC ',/,
     &              6X,F4.2,'  Effectiveness of Test and Repair ',
     &              'program vs. Test Only, for CO ',/,
     &              6X,F4.2,'  Effectiveness of Test and Repair ',
     &              'program vs. Test Only, for NOx')
        WRITE(*,271)(IAGE,VMT(IAGE),IAGE=1,25)
 271    FORMAT(/,' Vehicle miles travelled summary (vehicle age, ',
     &         'vehicle miles/year)',5(/,10(1X,I5)))
        PRINT *,' '
C
C Write out RSD effectivenesses used in Options 1 and 2
C
        WRITE (*,295)
 295    FORMAT(1X,'RSD Effectivenesses ',
     &            'for CO cutpoints increasing from 0.5% to 7.5%',/,
     &         1X,'HC',T28,'CO',T54,'NOx',/,
     &         1X,'Tech 1  ','Tech 2  ','Tech 4+ ',
     &          '  Tech 1  ','Tech 2  ','Tech 4+ ',
     &          '  Tech 1  ','Tech 2  ','Tech 4+ ')
C
        DO 89 ICUT=1,15
          WRITE (*,290)((EXCESS(ITECH,ICUT,IP),ITECH=1,3),IP=1,3)
 290      FORMAT (3(3(1X,F7.4),2X))
 89     CONTINUE
C
        PRINT *,' '
      ELSE
C
        IF (OPTION.EQ.2) THEN
          WRITE(*,275)(IAGE,TOTAL(IAGE),SENT(IAGE),IAGE=1,25)
 275      FORMAT(' Option #2 input data file information:',
     &           /,' Vehicle age, number registered, number sent to ',
     &         'RSD IM program',5(/,5(2X,I2,1X,I6,1X,I4)))
          PRINT *,' '
C
C Write out RSD effectivenesses used in Options 1 and 2
C
          WRITE (*,295)
C295      FORMAT(1X,'RSD Effectivenesses ',
C    &              'for CO cutpoints increasing from 0.5% to 7.5%',/,
C    &           1X,'HC',T28,'CO',T54,'NOx',/,
C    &           1X,'Tech 1  ','Tech 2  ','Tech 4+ ',
C    &            '  Tech 1  ','Tech 2  ','Tech 4+ ',
C    &            '  Tech 1  ','Tech 2  ','Tech 4+ ')
C
          DO 90 ICUT=1,15
            WRITE (*,290)((EXCESS(ITECH,ICUT,IP),ITECH=1,3),IP=1,3)
C290        FORMAT (3(3(1X,F7.4),2X))
 90       CONTINUE
C
        ELSE
C
C OPTION is 3
C
          WRITE(*,280)(IAGE,CFAIL(IAGE),RFAIL(IAGE),IAGE=1,25)
 280      FORMAT(' Option #3 input data file information:',
     &          /,' Vehicle age, number failing IM now, number ',
     &          'expected to fail next cycle',5(/,5(2X,I2,1X,I6,1X,I4)))
          PRINT *,' '
C
          WRITE (*,296)
 296      FORMAT(1X,'RSD average benefits per failure ',
     &              'for CO cutpoints increasing from 0.5% to 7.5%',/,
     &           1X,'HC',T28,'CO',T54,'NOx',/,
     &           1X,'Tech 1  ','Tech 2  ','Tech 4+ ',
     &            '  Tech 1  ','Tech 2  ','Tech 4+ ',
     &            '  Tech 1  ','Tech 2  ','Tech 4+ ')
C
        DO 91 ICUT=1,15
          WRITE (*,290)((EOPT3(ITECH,ICUT,IP),ITECH=1,3),IP=1,3)
C290      FORMAT (3(3(1X,F7.4),2X))
 91     CONTINUE
        ENDIF
C
      ENDIF
C
C From option variable, choose method of calculating F and E
C
      IF (OPTION.EQ.1) THEN
        CALL R1(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
      ELSE
C
        IF (OPTION.EQ.2) THEN
          CALL R2(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
        ELSE
C
C Option is 3
C
          CALL R3(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
        ENDIF
C
      ENDIF
C
C Choose the IM# and TECH# pair where # corresponds to the action
C variable
C
      IF (ACTION.EQ.1) THEN
        CALL IM1(IN1981,OUT198,NVSEEB,UEXCE4,RSDD)
        CALL TECH1(INT12,OUTT12,NVSEEB,UEXCE1,UEXCE2,RSDD)
      ELSE
C
        IF (ACTION.EQ.2) THEN
          CALL IM2(IN1981,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
          CALL TECH2(INT12,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,RSDD)
        ELSE
C
          IF (ACTION.EQ.3) THEN
            CALL IM3(IN1981,IN198H,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
            CALL TECH3(INT12,INT12H,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,
     &                 RSDD)
          ELSE
C
            IF (ACTION.EQ.4) THEN
              CALL IM4(IN1981,OUT198,NVSEEA,UEXCE4,RSDD)
              CALL TECH4(INT12,OUTT12,NVSEEA,UEXCE1,UEXCE2,RSDD)
            ELSE
C
C ACTION=5
C
              CALL IM5(IN1981,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
              CALL TECH5(INT12,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,RSDD)
C
              CALL IM5(IN198H,OUT19H,NVSEEA,UEXCE4,NVSEEB,RSDD)
              CALL TECH5(INT12H,OUTT1H,NVSEEA,UEXCE1,NVSEEB,UEXCE2,RSDD)
            END IF
C
          END IF
C
        END IF
C
      END IF
C
 99   CONTINUE
      RETURN
      END
