      SUBROUTINE R2(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
C
C Subroutine R2 calculates the proper values of E and F for
C option 2
C
C Subroutine calls:  none
C
C Input: 
C by user:  none
C common blocks:  OP1, OP2
C data file(s): none
C subroutine arguments: none
C 
C Output:
C by screen:  none
C common blocks:  none
C data file(s):  none
C subroutine arguments:  UEXCE1, NVSEEA, UEXCE2, NVSEEB, UEXCE4
C
C Array subscripts:
C
C CUTS(3)        - CUTS(ITECH)
C EFF(3)         - EFF(IP)
C EXCESS(3,15,3) - EXCESS(1 is Tech type 1, 2 is 2, & 3 is 4+,ICUT,IP)
C NVSEEA(25)     - NVSEEA(IBY)
C NVSEEB(25)     - NVSEEB(IBY)
C SENT(25)       - SENT(IBY)
C TOTAL(25)      - TOTAL(IBY)
C UEXCE1(3)      - UEXCE1(IP)
C UEXCE2(3)      - UEXCE2(IP)
C UEXCE4(3)      - UEXCE4(IP)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EXCESS  R   Sacramento Study data for HC, CO, and NOx fractions of IM
C              excess identified for a particular cutpoint of CO for a
C              particular Tech type:  EXCESS( Tech type, ICUT,IP) if
C              defaults in DATA2 were used--otherwise, this data is
C              provided by user
C IBY     I   Benefit year
C ICUT    I   Counter for cutpoint array index (ICUT=1, 2, ... , 8
C              corresponds to 0.5%, 1.0%, ... , 4.0% CO test cutpoints)
C IP      I   Counter for pollutants
C NVSEEA  R   Fractions of vehicles seen by RSD in an annual program by
C              year, provided by user
C NVSEEB  R   Fractions of vehicles seen by RSD in a biennial program by
C              year, povided by user
C OPTION  I   Option--see RSDDRV
C RCUT    R   Real value of counter for cutpoint array index
C SENT    I   No. of veh. sent to special IM via RSD (commitment) by age
C TOTAL   I   Total no. of veh. for each age
C UEXCE1  R   HC, CO, and NOx fractions of IM excess identified by RSD,
C              calculated from UEXCES using user-supplied RSD CO test
C              cutpoints; used by TECH12 to modify pre-1975 data
C UEXCE2  R   Like UEXCE1, but used by TECH12 to modify 1975-1980 data
C UEXCE4  R   Like UEXCE1, but used by IMDATA to modify post-1980 data
C VMT     I   Vehicle Miles Travelled (per year), by age
C
C
C Notes:
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      INTEGER AGE, IBY, ICUT, IP, NUMBER, OPTION, SCAN, SENT(25), TIMES
      INTEGER TOTAL(25),VMT(25)
C
      REAL CUTS(3), EFF(3), EXCESS(3,15,3), NVSEEA(25), NVSEEB(25), RCUT
      REAL UEXCE1(3), UEXCE2(3), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP2/SENT,TOTAL
C
C EXCESS is set up as follows
C
C Fortran first fastest convention for indices:  UEXCES(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (Tech 1, 0.5%, HC), (Tech 2, 0.5%, HC),
C (Tech 4, 0.5%, HC), (Tech 1, 1.0%, HC), ...
C                  (1,1,1)  (2,1,1)  (3,1,1)  (1,2,1)  (2,2,1)  (3,2,1)
C
C Set up excess emissions identified arrays
C
C Set up proper cutpoint data by interpolating the discrete values
C in array EXCESS(tech type, cutpoint, pollutant).  First evaluate
C pre-1975 (Tech 1) data,
C
      DO 81 IP=1,3
C
C If CUTS(1) = 99.9, fill the UEXCE1 array with 0. in order to
C indicate processing is to be skipped for pr-1975 (Tech 1) data
C
        IF (CUTS(1).EQ.99.9) THEN
          UEXCE1(IP)=0.
          GO TO 81
        END IF
C
C First, calculate the two cutpoint array indices corresponding to the
C data points in the array nearest to the given cutpoint:
C 0.5 <=> 1, 1.0 <=> 2, ... , 4.0 <=> 8, ... , 7.5 <=> 15
C
        ICUT=INT(CUTS(1)*2)
        RCUT=FLOAT(ICUT)
C
C If ICUT=15, avoid sending the array out of bounds:
C
        IF (ICUT.EQ.15) THEN
          UEXCE1(IP)=EXCESS(1,ICUT,IP)
          GO TO 81
        END IF
C
C ICUT is not 15, so interpolate:
C
        UEXCE1(IP)=EXCESS(1,ICUT,IP)+
     &             ( EXCESS(1,ICUT+1,IP) - EXCESS(1,ICUT,IP) )*
     &             ( CUTS(1) - RCUT/2 )/0.5
C
 81   CONTINUE
C
C ... then evaluate Tech 2 data,
C
      DO 82 IP=1,3
C
C If CUTS(2) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for 1975-1980 (Tech 2) data
C
        IF (CUTS(2).EQ.99.9) THEN
          UEXCE2(IP)=0.
          GO TO 82
        END IF
C
        ICUT=INT(CUTS(2)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE2(IP)=EXCESS(2,ICUT,IP)
          GO TO 82
        END IF
C
        UEXCE2(IP)=EXCESS(2,ICUT,IP)+
     &             ( EXCESS(2,ICUT+1,IP) - EXCESS(2,ICUT,IP) )*
     &             ( CUTS(2) - RCUT/2 )/0.5
C
 82   CONTINUE
C
C ... and then evaluate post-1980 data.
C
      DO 84 IP=1,3
C
C If CUTS(3) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for post-1980 (Tech 4+) data
C
        IF (CUTS(3).EQ.99.9) THEN
          UEXCE4(IP)=0.
          GO TO 84
        END IF
C
        ICUT=INT(CUTS(3)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE4(IP)=EXCESS(3,ICUT,IP)
          GO TO 84
        END IF
C
        UEXCE4(IP)=EXCESS(3,ICUT,IP)+
     &             ( EXCESS(3,ICUT+1,IP) - EXCESS(3,ICUT,IP) )*
     &             ( CUTS(3) - RCUT/2 )/0.5
C
 84   CONTINUE
C
C Calculate F values, NVSEEA and NVSEEB
C
      DO 85 IBY=1,25
C
C Take age exemptions into account.
C
        IF (IBY.LT.INT(AGE)) THEN
          NVSEEA(IBY)=0.
        ELSE
          NVSEEA(IBY)=FLOAT(SENT(IBY))/FLOAT(TOTAL(IBY))
        ENDIF
C
        NVSEEB(IBY)=NVSEEA(IBY)
C
 85   CONTINUE
C
      RETURN
      END
