      SUBROUTINE R3(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
C
C Subroutine R3 calculates the proper values of E and F for
C option 3
C
C Subroutine calls:  none
C
C Input: 
C by user:  none
C common blocks:  OP1, OP3
C data file(s): none
C subroutine arguments: none
C 
C Output:
C by screen:  none
C common blocks:  none
C data file(s):  none
C subroutine arguments:  UEXCE1, NVSEEA, UEXCE2, NVSEEB, UEXCE4
C
C Array subscripts:
C
C CFAIL(25)      - CFAIL(IBY)
C CUTS(3)        - CUTS(ITECH)
C EFF(3)         - EFF(IP)
C EOPT3(3,15,3)  - EOPT3(Tech type, ICUT, IP)
C EXCESS(3,15,3) - EXCESS(Tech type, ICUT, IP)
C NVSEEA(25)     - NVSEEA(IBY)
C NVSEEB(25)     - NVSEEB(IBY)
C RFAIL(25)      - RFAIL(IBY)
C UEXCE1(3)      - UEXCE1(IP)
C UEXCE2(3)      - UEXCE2(IP)
C UEXCE4(3)      - UEXCE4(IP)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CFAIL   I   No. of veh. by age that failed the current year's IM
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EOPT3   R   User supplied data for HC, CO, and NOx fractions of IM
C              excess identified for a particular cutpoint of CO for a
C              particular Tech type:  EOPT3( Tech type, ICUT,IP):  E
C              values for Option 3
C EXCESS  R   Like EOPT3, but for Options 1 and 2
C IBY     I   Benefit year
C ICUT    I   Counter for cutpoint array index (ICUT=1, 2, ... , 8
C              corresponds to 0.5%, 1.0%, ... , 4.0% CO test cutpoints)
C IP      I   Counter for pollutants
C MAXEX   R   Maximum of the excesses UEXCE1(IP), UEXCE2(IP), and
C              UEXCE4(IP) for the CO cutpoint in use
C NVSEEA  R   Fractions of vehicles seen by RSD in an annual program by
C              year, provided by user
C NVSEEB  R   Fractions of vehicles seen by RSD in a biennial program by
C              year, povided by user
C RCUT    R   Real value of counter for cutpoint array index
C RFAIL   I   Commitment for no. of veh. to fail the RSD IM program in
C              the upcoming year.
C UEXCE1  R   HC, CO, and NOx fractions of IM excess identified by RSD,
C              calculated from UEXCES using user-supplied RSD CO test
C              cutpoints; used by TECH12 to modify pre-1975 data
C UEXCE2  R   Like UEXCE1, but used by TECH12 to modify 1975-1980 data
C UEXCE4  R   Like UEXCE1, but used by IMDATA to modify post-1980 data
C VMT     I   Vehicle Miles Travelled (per year), by age
C
C
C Notes:
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      INTEGER AGE, CFAIL(25), IBY, ICUT, IP, NUMBER, OPTION, RFAIL(25)
      INTEGER SCAN, TIMES, VMT(25)
C
      REAL CUTS(3), EFF(3), EOPT3(3,15,3), EXCESS(3,15,3), MAXEX
      REAL NVSEEA(25), NVSEEB(25), RCUT, UEXCE1(3), UEXCE2(3), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP3/CFAIL,RFAIL,EOPT3
C
C Set up excess emissions identified arrays
C
C Set up proper cutpoint data by interpolating the discrete values
C in array EOPT3(tech type, cutpoint, pollutant).  First evaluate
C pre-1975 (Tech 1) data,
C
      DO 81 IP=1,3
C
C If CUTS(1) = 99.9, fill the UEXCE1 array with 0. in order to
C indicate processing is to be skipped for pr-1975 (Tech 1) data
C
        IF (CUTS(1).EQ.99.9) THEN
          UEXCE1(IP)=0.
          GO TO 81
        END IF
C
C First, calculate the two cutpoint array indices corresponding to the
C data points in the array nearest to the given cutpoint:
C 0.5 <=> 1, 1.0 <=> 2, ... , 4.0 <=> 8, ... , 7.5 <=> 15
C
        ICUT=INT(CUTS(1)*2)
        RCUT=FLOAT(ICUT)
C
C If ICUT=15, avoid sending the array out of bounds:
C
        IF (ICUT.EQ.15) THEN
          UEXCE1(IP)=EOPT3(1,ICUT,IP)
          GO TO 81
        END IF
C
C ICUT is not 15, so interpolate:
C
        UEXCE1(IP)=EOPT3(1,ICUT,IP)+
     &             ( EOPT3(1,ICUT+1,IP) - EOPT3(1,ICUT,IP) )*
     &             ( CUTS(1) - RCUT/2 )/0.5
C
 81   CONTINUE
C
C ... then evaluate Tech 2 data,
C
      DO 82 IP=1,3
C
C If CUTS(2) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for 1975-1980 (Tech 2) data
C
        IF (CUTS(2).EQ.99.9) THEN
          UEXCE2(IP)=0.
          GO TO 82
        END IF
C
        ICUT=INT(CUTS(2)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE2(IP)=EOPT3(2,ICUT,IP)
          GO TO 82
        END IF
C
        UEXCE2(IP)=EOPT3(2,ICUT,IP)+
     &             ( EOPT3(2,ICUT+1,IP) - EOPT3(2,ICUT,IP) )*
     &             ( CUTS(2) - RCUT/2 )/0.5
C
 82   CONTINUE
C
C ... and then evaluate post-1980 data.
C
      DO 84 IP=1,3
C
C If CUTS(3) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for post-1980 (Tech 4+) data
C
        IF (CUTS(3).EQ.99.9) THEN
          UEXCE4(IP)=0.
          GO TO 84
        END IF
C
        ICUT=INT(CUTS(3)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE4(IP)=EOPT3(3,ICUT,IP)
          GO TO 84
        END IF
C
        UEXCE4(IP)=EOPT3(3,ICUT,IP)+
     &             ( EOPT3(3,ICUT+1,IP) - EOPT3(3,ICUT,IP) )*
     &             ( CUTS(3) - RCUT/2 )/0.5
C
 84   CONTINUE
C
C
C Reset RFAIL values if necessary to cap the effectivenesses *
C fractions of vehicles seen values at 1.0.
C
      MAXEX = AMAX1( UEXCE1(1), UEXCE1(2), UEXCE1(3),
     &               UEXCE2(1), UEXCE2(2), UEXCE2(3),
     &               UEXCE4(1), UEXCE4(2), UEXCE4(3) )
C
      IF (MAXEX.NE.0.) THEN
C
C Check to see if any model year values of RFAIL are too high.
C
        DO 90 IBY=1,25
C
          IF ( MAXEX*FLOAT(RFAIL(IBY))/FLOAT(CFAIL(IBY)).GT.1. ) THEN
            WRITE(*,200)IBY,RFAIL(IBY),INT( FLOAT(CFAIL(IBY))/MAXEX )
 200        FORMAT(/,1X,'Input no. of IM failures via RSD (commitment)',
     & ' in model yr. ',I2,' is ',I4,/,' and is too large.  Resetting',
     & ' to ',I4)
            RFAIL(IBY)=INT( FLOAT(CFAIL(IBY))/MAXEX )
          ENDIF
C
 90     CONTINUE
C
      ENDIF
C
C
C
C Calculate F values
C
      DO 85 IBY=1,25
C
C Take age exemptions into account.
C
        IF (IBY.LT.INT(AGE)) THEN
          NVSEEA(IBY)=0.
        ELSE
          NVSEEA(IBY)=FLOAT(RFAIL(IBY))/FLOAT(CFAIL(IBY))
        END IF
C
        NVSEEB(IBY)=NVSEEA(IBY)
C
 85   CONTINUE
C
      RETURN
      END
