      SUBROUTINE TECH3(INT12,INT12H,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,
     &                 RSDD)
C
C TECH3
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD)
C from the existing Tech 1 & 2 credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  files whose names are passed in INT12 and INT12H 
C subroutine arguments:  INT12, INT12H, OUTT12, NVSEEA, UEXCE1,
C                        NVSEEB, UEXCE2, RSDD
C
C Output:
C by screen:  none
C common block(s):  none used
C data file(s):  file whose name is passed in OUTT12
C subroutine arguments:  none
C
C Array subscripts:
C
C CRHCO(19,20,5,2)  - CRHCO(IBY,IAGE1,ISTR,ITECH)
C CRHHC(19,20,5,2)  - CRHHC(IBY,IAGE1,ISTR,ITECH)
C CR12CO(19,20,5,2) - CR12CO(IBY,IAGE1,ISTR,ITECH)
C CR12HC(19,20,5,2) - CR12HC(IBY,IAGE1,ISTR,ITECH)
C CUTS(3)           - CUTS(ITECH)
C EFF(3)            - EFF(IP)
C EXCESS(3,15,3)    - EXCESS(ITECH,cutpoint,pollutant)
C NVSEEA(25)        - NVSEEA(age of vehicle)
C NVSEEB(25)        - NVSEEB(age of vehicle)
C UEXCE1(3)         - UEXCE1(pollutant:  1=HC, 2=CO, & 3=NOx)
C UEXCE2(3)         - UEXCE2(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)           - VMT(IBY)
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C ANNUAL  R   temporary Annual credit
C ANNUAH  R   temporary Annual credit, Retest-hybrid
C BIENNH  R   temporary Biennial credit, Retest-hybrid
C CRHCO   R   Array of Tech 1 & 2 CO IM credits from TC12H.D type file
C CRHHC   R   Array of Tech 1 & 2 HC IM credits from TC12H.D type file
C CRNCO   R   Array of new Tech 1 & 2 CO IM credits
C CRNHC   R   Array of new Tech 1 & 2 HC IM credits
C CR12CO  R   Array of Tech 1 & 2 CO IM credits
C CR12HC  R   Array of Tech 1 & 2 HC IM credits
C CKUTCO  R   Smart line original CO cutpoint from TC12H.D type file
C CKUTHC  R   Smart line original HC cutpoint from TC12H.D type file
C CKUTNO  R   Smart line original NO cutpoint from TC12H.D type file
C CUTCO   R   Smart line original CO cutpoint
C CUTHC   R   Smart line original HC cutpoint
C CUTNO   R   Smart line original NO cutpoint
C CUTS    R   Array of RSD CO cutpoints by Tech type:  1, 2, and 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   An extra flag in IMDATA.FOR, in TECH12.FOR, it serves as the
C              IMLFG (see below) for Tech 2 data
C EXCESS  R   See routines R1 and R2
C HYBFLG  I   Hybrid program flag
C IAGE    I   Counter for age when first inspected 
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   Tech 1 I/M flag:  1 if no RSD program modifications done on
C              Tech 1 part of TECH12.D; 2 if Tech 1 data was changed
C INT12   C   Character string name of the TECH12.D type input file
C INT12H  C   Character string name of the TC12H.D type input file
C ISMART  I   Counter for Smart strip
C ISTR    I   Counter for Stringency
C ITECH   I   Counter for Tech type
C NUMBER  I   Total number of veh. subject to inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUTT12  C   Character string name of the TECDATA.D type output file
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array of the Smart strip values, retest-hybrid data
C SMART   I   Array of the Smart strip values, TECH12.D type data
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line.
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE1  R   Effectiveness of RSD, Tech type 1 vehicles
C UEXCE2  R   Effectiveness of RSD, Tech type 2 vehicles
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Annual and biennial information is stored in an upper and
C         lower triangular fashion.
C 10-July-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2 
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
      CHARACTER INT12*40, INT12H*40, OUTT12*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IAGE, IBY, IMFLG, ISMART, ISTR
      INTEGER ITECH, NUMBER, OLDFLG, OPTION, SCAN, SMARK(4), SMART(4)
      INTEGER TIMES, VMT(25)
C
      REAL ANNUAL, ANNUAH, BIENNH, CKUTCO, CKUTHC, CKUTNO
      REAL CRHCO(19,20,5,2), CRHHC(19,20,5,2), CRNCO(19,20,5,2)
      REAL CRNHC(19,20,5,2), CR12CO(19,20,5,2), CR12HC(19,20,5,2)
      REAL CUTCO, CUTHC, CUTNO, CUTS(3), EFF(3), EXCESS(3,15,3)
      REAL NVSEEA(25), NVSEEB(25), UEXCE1(3), UEXCE2(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C If old data, OLDFLG is set to 1; first initialize OLDFLG to 0
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1974 and older model ',
     &            'years and 1975 through 1980 model years ',/,
     &           ' vehicles I/M credits to include Remote ', 
     &            'Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '---------------------------------------')
C
C Open filename in INT12 for input as unit 12
C Open filename in INT12H for input as unit 14
C Open filename in OUTT12 for output as unit 13
C
      OPEN(12,FILE=INT12, ERR=300,STATUS='OLD')
      OPEN(14,FILE=INT12H,ERR=305,STATUS='OLD')
      OPEN(13,FILE=OUTT12,ERR=310)
C
C Since the form of the data in Tech12 type files involves essentially 
C just one data block, these blocks can be read in at the same time.
C
 90   CONTINUE
C
      READ(12,100,END=97,ERR=320) (SMART(ISMART),ISMART=1,4),
     &     CUTHC,CUTCO,CUTNO,THREE
 100  FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,A3)
C
      READ(THREE,102,ERR=15) HYBFLG,IMFLG,ETCFLG
 102  FORMAT(3I1)
C
      GO TO 16
C
 15   CONTINUE
C
C When there is a misread of the flags, the data is of the old type;
C set OLDFLG to 1 and skip the check on IMFLG
C
      OLDFLG=1
C
 16   CONTINUE
C
C Since the hybrid file is unchanged, don't read into the flags area.
C
      READ(14,103,END=97,ERR=322) (SMARK(ISMART),ISMART=1,4),
     &     CKUTHC,CKUTCO,CKUTNO
 103  FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0)
C
C Reading Smart lines and associated data from test-only credits
C input file and Retest-hybrid credits input file
C
C If the Smart lines of the two input files do not agree, issue error
C and halt.
C
      IF ( (SMART(1).NE.SMARK(1)).OR.(SMART(2).NE.SMARK(2)).OR.
     &     (SMART(3).NE.SMARK(3)).OR.(SMART(4).NE.SMARK(4)).OR.
     &     (CUTCO.NE.CKUTCO)     .OR.(CUTHC.NE.CKUTHC)     .OR.
     &     (CUTNO.NE.CKUTNO) ) THEN 
        GO TO 324
      END IF
C
C Check IMFLG only if data is new
C
      IF (OLDFLG.EQ.0) THEN
C
C If IMFLG is not one, this means that Tech 1 or Tech 2 data
C has been already changed using RSD effects.  Issue error and halt.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 326
        END IF
C
      END IF
C
C Read in Annual and Biennial credits for HC
C Loop for the two (2) ITECHs stored in the files.
C
      DO 10 ITECH=1,2
C
C Loop for the five (5) stringency values in the files.
C
        DO 12 ISTR=1,5
C
C Loop for the values in the records
C
          DO 14 IAGE1=1,20
C
C Read data from the ipu file INT12
C
            READ(12,110,END=330,ERR=334)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 110       FORMAT(19F4.3)
C
C Read data from the input file INT12H
C
        READ(14,110,END=336,ERR=338)
     & (CRHHC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
C110       FORMAT(19F4.3)
  14      CONTINUE
C
  12    CONTINUE

  10  CONTINUE
C
C Read in Annual and Biennial credits for CO
C
      DO 20 ITECH=1,2
C
        DO 22 ISTR=1,5
C
          DO 24 IAGE1=1,20
C
C Read in data from the input file INT12
C
            READ(12,110,END=340,ERR=344)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
C110        FORMAT(19F4.3)
C
C Read data from the input file INT12H
C
            READ(14,110,END=346,ERR=348)
     & (CRHCO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
C110        FORMAT(19F4.3)
 24       CONTINUE
C
 22     CONTINUE

 20   CONTINUE
C
C Process the data and then write it to the output file
C Creating new Smart line and associated data
C
      DO 30 ITECH=1,2
C
        DO 32 ISTR=1,5
C
          DO 34 IBY=1,19
C
            DO 36 IAGE=1,19
C
C Only let the benefit year counter IBY and the age at first
C inspection counter be in the upper triangular region of Annual
C data.  (Another way of looking at this is that the actual age of a
C vehicle is its age at first inspection plus the time elapsed since its
C first inspection--current benefit year minus first benefit year.
C The actual age is thus IAGE+IBY-1.  Since actual age cannot exceed 
C 19 years, IAGE+IBY-1 must be .LE. 19.)
C
              IF ((IBY+IAGE).GT.20) THEN
                GO TO 34
              END IF
C
C HC credits
C
              ANNUAL=CR12HC(IBY,IAGE,ISTR,ITECH)
              ANNUAH=CRHHC(IBY,IAGE,ISTR,ITECH)
              BIENNH=CRHHC(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CRNHC(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE1(1) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE1(1) )
C
C Note:  new annual credit = Test-only annual credit * F * E +
C Hybrid-retest annual credit * (1-F*E).  The data from
C the input files consists of Test-only credit.
C
                CRNHC(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE1(1) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE1(1) )
C
C Note:  new biennial credit = Test-only annual credit * F * E +
C Hybrid-retest biennial credit * (1-F*E).
C
              ELSE
C
C ITECH is 2
C
                CRNHC(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE2(1) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE2(1) )
C
                CRNHC(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE2(1) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE2(1) )
C
C
              END IF
C
C Note that NVSEEA and NVSEEB are functions of the actual age of
C the vehicle.  See above.
C
C CO credits
C
              ANNUAL=CR12CO(IBY,IAGE,ISTR,ITECH)
              ANNUAH=CRHCO(IBY,IAGE,ISTR,ITECH)
              BIENNH=CRHCO(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CRNCO(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE1(2) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE1(2) )
C
                CRNCO(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE1(2) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE1(2) )
C
              ELSE
C
C ITECH is 2
C
                CRNCO(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE2(2) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE2(2) )
C
                CRNCO(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE2(2) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE2(2) )
C
              END IF
C
 36         CONTINUE
C
 34       CONTINUE
C
 32     CONTINUE
C
 30   CONTINUE
C
C Rewriting Smart line and associated new annual and new biennial
C credits to the output file
C
C If OLDFLG is not 1, then data is of the new type; output the
C following
C
      IF (OLDFLG.NE.1) THEN
        WRITE(13,240,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,HYBFLG,ETCFLG,OPTION,RSDD
  240   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,I1,'2',I1,' New ',
     &         'credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      ELSE
C
C Old type data
C
        WRITE(13,242,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,OPTION,RSDD
  242   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,' 2 ',' New ',
     &         'credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      END IF
C
C Write the HC data
C
      DO 40 ITECH=1,2
C
        DO 42 ISTR=1,5
C
          DO 44 IAGE1=1,20
            WRITE(13,250,ERR=350)
     & (CRNHC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  250       FORMAT(19F4.3)
  44      CONTINUE
C
  42    CONTINUE

  40  CONTINUE
C
C Write the CO data
C
      DO 50 ITECH=1,2
C
        DO 52 ISTR=1,5
C
          DO 54 IAGE1=1,20
            WRITE(13,250,ERR=350)
     & (CRNCO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 54       CONTINUE
C
 52     CONTINUE

 50   CONTINUE
C
C Done.
C
      GO TO 97
C
C ---------------------------
C CONSOLIDATED ERROR MESSAGES
C ---------------------------
C
 300  CONTINUE  
      WRITE(*,301)INT12
 301  FORMAT(/,  ' ERROR OPENING TEST-ONLY INPUT CREDITS ',
     &            'FILE ',A40)
      GOTO 96
C
 305  CONTINUE
      WRITE(*,306)INT12H
 306  FORMAT(/,  ' ERROR OPENING RETEST-HYBRID INPUT ',
     &            'CREDITS FILE ',A40)
      GOTO 96
C
 310  CONTINUE
      WRITE(*,311)OUTT12
 311  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GOTO 96
C
 320  CONTINUE
      WRITE(*,321)INT12
 321  FORMAT(/,  ' ERROR READING SMART LINE FROM TEST-ONLY ',
     &            'INPUT CREDITS FILE ',A40)
      GOTO 96
C
 322  CONTINUE
      WRITE(*,323)INT12H
 323  FORMAT(/,  ' ERROR READING SMART LINE FROM ',
     &            'RETEST-HYBRID INPUT CREDITS FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 324  CONTINUE
      WRITE(*,325)
 325  FORMAT(/,  ' ERROR SMART LINES FROM THE TWO INPUT ',
     &            'FILES DO NOT MATCH')
      GOTO 96
C
 326  CONTINUE
      WRITE(*,327)INT12
 327  FORMAT(/,  ' ERROR TECH 1 OR TECH 2 DATA HAVE ',
     &            'ALREADY BEEN CHANGED IN TEST-ONLY INPUT ',/,
     &           ' CREDITS FILE ',A40)
      GOTO 96
C
 330  CONTINUE
      WRITE(*,331)INT12
 331  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING HC ',
     &            'CREDITS FROM TEST-ONLY INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 334  CONTINUE
      WRITE(*,335)INT12
 335  FORMAT(/,  ' ERROR READING HC CREDITS FROM TEST-ONLY ',
     &            'INPUT FILE ',A40)
      GOTO 96
C
 336  CONTINUE
      WRITE(*,337)INT12H
 337  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING HC ',
     &            'CREDITS FROM RETEST-HYBRID INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 338  CONTINUE
      WRITE(*,339)INT12H
 339  FORMAT(/,  ' ERROR READING HC CREDITS FROM ',
     &            'RETEST-HYBRID INPUT FILE ',A40)
      GOTO 96
C
 340  CONTINUE
      WRITE(*,341)INT12
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING CO ',
     &            'CREDITS FROM TEST-ONLY INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 344  CONTINUE
      WRITE(*,345)INT12
 345  FORMAT(/,  ' ERROR READING CO CREDITS FROM TEST-ONLY ',
     &            'INPUT FILE ',A40)
      GOTO 96
C
 346  CONTINUE
      WRITE(*,347)INT12H
 347  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING CO ',
     &            'CREDITS FROM RETEST-HYBRID INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 348  CONTINUE
      WRITE(*,349)INT12H
 349  FORMAT(/,  ' ERROR READING CO CREDITS FROM ',
     &            'RETEST-HYBRID INPUT FILE ',A40)
      GOTO 96
C
 350  CONTINUE
      WRITE(*,351)OUTT12
 351  FORMAT(/,  ' ERROR WRITING TO OUTPUT FILE ',A40)
      GOTO 96
C
C ---------------------------------
C CLOSE DATA FILES AND EXIT PROGRAM
C ---------------------------------
C
 96   WRITE(*,'(A)')'0CONVERSION ENDED ABNORMALLY.'
      GOTO 98
C
 97   WRITE(*,'(A)')'0Conversion ended normally.'
C
 98   CONTINUE
C
      CLOSE (13)
      CLOSE (14)
      CLOSE (12)
C
      RETURN
      END
